Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog <https://keepachangelog.com/en/1.0.0/>`_,
and this project adheres to `Semantic Versioning <https://semver.org/spec/v2.0.0.html>`_.

[Unreleased]
------------

[0.3.2] - 2025-06-07
--------------------

Added
~~~~~
- readthedocs documentation

Fixed
~~~~~
- column_descriptions API
- logo url

[0.3.0] - 2025-06-01
--------------------

Added
~~~~~
- Beta Release with major refactoring

[0.2.1] - 2025-04-29
--------------------

Added
~~~~~
- Added default column names to 'column_description' and 'column_types' attributes
- Added changelog system

[0.2.0] - 2025-04-08
--------------------

Added
~~~~~
- Initial release of superpandas
- Basic pandas functionality with AI capabilities

[0.1.0]
-------

Added
~~~~~
- Initial project setup with basic pandas enhancements

.. [0.3.2]: https://github.com/superpandas-ai/superpandas/compare/v0.3.0...v0.3.2
.. [0.3.0]: https://github.com/superpandas-ai/superpandas/compare/v0.2.1...v0.3.0
.. [0.2.1]: https://github.com/superpandas-ai/superpandas/compare/v0.2.0...v0.2.1
.. [0.2.0]: https://github.com/superpandas-ai/superpandas/compare/v0.1.0...v0.2.0
.. [0.1.0]: https://github.com/superpandas-ai/superpandas/releases/tag/v0.1.0 
.. [0.3.0]: https://github.com/superpandas-ai/superpandas/releases/tag/v0.3.0 